Top

    Powerbase Badalona 2024
    Badalona, Spain
    May 4th 2024
    2R+F
    25 players
    Miquel Jorge Tortajada
    https://www.vekn.net/event-calendar/event/11435

    A brief explanation about the final, from my point of view.
    With 1GW4VP I placed second (new salubri powerbleed), so a quite good position to pick my seat.
    The other finalists were:
    Marc Alvarez (1st) Matasuntha rush
    Albert Dulcet (3rd)  Marie Faucigny with equipments (strange deck)
    Xavier Macias (4th) Ravnos
    Germán Sánchez (Gangrel block)
    When I got the chance to pick my place the order was already:
    Xavier Macias (Ravnos) -> Albert Dulcet (Marie Faucigny) -> Germán Sanchez (Gangrel block)
    I knew I didn't want to prey the gangrels, my thoughts about the Ravnos were that it was a toolboox with bleed reduction, so ideal choice was between Ravnos and Marie, but I was sure that Matasuntha would then place behind me so I risked it and placed myself between Gangrel and the Ravnos, hoping to get out early and put some pressure on my prey. Marc placed preying Albert.
    Pulled out Seraphina and had a GtU and a SM in hand with a freak drive, so was quite confident to get my second vampire early. Played seduction on the only Ravnos Xavier had, but unfortunately Kuyén decided to block me.
    - I know your deck- Were Germán's words, so I knew he wasn't going to let me play easily, so decided to bring my second vampire transferring from my pool.
    Matasuntha start putting quite some pressure on Marie, but I knew Albert playstyle, and he is a very resourceful person, and really hard to kill, so the Gangrels were free to roam, and a couple more joined Kuyén son enough.
    A bit later, Xavier discarded a Pentex, so having one in hand I knew there was my chance, so with a few tricks from the salubris I manage to give is pool quite a big bite, but not enough to oust him.
    Germán put some pressure on me, not heavy but steady with 2 or 3 bleeds per turn, I was lucky to get almost all my deflections, redirections and TM and that prevent me from dyeing and lowering Xavier's pool a bit. Then he played a risky move, bringing Club Illusion to the game with some sort of agreement with my anarch predator, that if he killed me, he would allow a couple of turns of peace so the Ravnos could recover.
    Matasuntha's attention suddenly faded from Marie and turned backwards, as she had 4 vampires with a potential bleed of 9 and Marc's pool was only at 13, so she multirushed backwards, torporizing 3 vampires. Albert offered to rescue 1 on order to safe Xavier and keep Matasuntha busy with him.
    On his turn, German tried to oust me with his full potential, he had previously recovered a Monkey Wrench with his Garibaldi, so I was ready for it and he failed.
    My second chance was right in front of me, and I wasn't going to waste it, so I jumped towards Xavier's exposed pool and this time I manage to successfully oust him, but even before I could savor my victory I felt Matasuntha's eyes upon me, so with my sweetest salubri voice I offered a deal, and after a few give and take we manage to get ourselves an understanding.
    Marc will not rush me, and I will not bleed him, and the first Monkey Wrench German played I will directly deflect to Albert, all the other bleeds I could deflect them to Marc. I knew it wasn't much of a deal, Albert would get heavy pressure again and the Gangrel will be free to roam around me, and so he did bringing a 5th vampire to the game, but it was too late and the finale concluded a few turns after.
    Special mention to Marie and her crew, who suffered repeatedly Matasuntha's rushes but manage to come back from torpor more times than it seems even possible.
    Hope you all like my chronicle and apologize for my limited English.
    Miki
    P.D. Hope I have reported it correctly, if something is missing let me know.

    Deck Name: Nuevos Salubri (New Salubri)

    Crypt (12 cards, min=20, max=32, avg=6.42)
    ------------------------------------------
    2x Abaddon    8	 AUS DOM FOR cel pot  Salubri:7
    2x Seraphina  8	 AUS DOM FOR cel tha  Salubri:7
    2x Aniel      6	 AUS DOM for	      Salubri:7
    2x Malachi    6	 AUS DOM FOR	      Salubri:7
    2x Opikun     5	 FOR aus dom	      Salubri:7
    1x Ilonka     7	 AUS DOM FOR tha      Salubri:7
    1x Yael	      4	 aus dom for	      Salubri:7

    Library (90 cards)
    Master (14; 1 trifle)
    1x Anarch Troublemaker
    2x Blood Doll
    1x Coven, The
    1x Direct Intervention
    1x Giant's Blood
    1x Meditative Grove
    2x Pentex(TM) Subversion
    4x Perfectionist
    1x Saulot's Healing Touch

    Action (19)
    6x Feast of the Soul's Secrets
    7x Govern the Unaligned
    6x Scouting Mission

    Action/Combat (6)
    6x Touch of Valeren

    Ally (1)
    1x Carlton Van Wyk

    Equipment (1)
    1x Heart of Nizchetus

    Action Modifier (32)
    4x Bonding
    3x Daring the Dawn
    6x Forced Confessional
    8x Freak Drive
    4x Seduction
    2x Threats
    5x Unleashing the Bestial Soul

    Reaction (17)
    5x Deflection
    2x Delaying Tactics
    3x Eyes of Argus
    3x On the Qui Vive
    2x Redirection
    2x Telepathic Misdirection